


Pretest
------------------------------

Please make sure you are logged into Runestone before beginning. Click the Start button when you are ready to begin the exam. You can only take the exam once.  Click on the Next button to go to the next question.  Click on the Prev button to go to the previous question.  Use the number buttons to jump to a particular question.   Click on the Finish Exam button after you have answered all the questions.

.. timed:: pretest_ex1_v2
    :noresult:
    :nofeedback:
    :nopause:
    :fullwidth:
    :timelimit: 20


    .. selectquestion:: pretest_ex1_q1_v2_mcq
       :fromid: e5mc11
       :points: 2

    .. selectquestion:: pretest_ex1_q2_v2_mcq
       :fromid: range_sum_start_one_change_by_two
       :points: 2

    .. selectquestion:: pretest_ex1_q3_v2_mcq
       :fromid: var-operations-math-with-mod-v2
       :points: 2

    .. selectquestion:: pretest_ex1_q4_v2_mcq
       :fromid: listEx_MC14
       :points: 2

    .. selectquestion:: pretest_ex1_q5_v2_pp
       :fromid: middle_way
       :points: 10

    .. selectquestion:: pretest_ex1_q6_v2_ac
       :fromid: funct_loops_writecode1q
       :points: 10

    .. selectquestion:: pretest_ex1_q7_v3_ac
       :fromid: prestest_is_ascending_ac
       :points: 10
